@@ -163,7 +163,7 @@ void send_file_entry(struct file_struct *file,int f,unsigned base_flags)
   if (file->gid == last_gid) flags |= SAME_GID;
   if (file->modtime == last_time) flags |= SAME_TIME;
 
-  for (l1=0;lastname[l1] && fname[l1] == lastname[l1];l1++) ;
+  for (l1=0;lastname[l1] && (fname[l1] == lastname[l1]) && (l1 < 255);l1++) ;  
   l2 = strlen(fname) - l1;
 
   if (l1 > 0) flags |= SAME_NAME;
@@ -513,7 +513,7 @@ static void send_directory(int f,struct file_list *flist,char *dir)
 	d = opendir(dir);
 	if (!d) {
 		io_error = 1;
-		rprintf(FERROR,"%s: %s\n",
+		rprintf(FERROR,"opendir(%s): %s\n",
 			dir,strerror(errno));
 		return;
 	}
@@ -625,8 +625,11 @@ struct file_list *send_file_list(int f,int argc,char *argv[])
 				strlcpy(lastpath, fname, sizeof(lastpath)-1);
 				*p = '/';
 				for (p=fname+1; (p=strchr(p,'/')); p++) {
+					int copy_links_saved = copy_links;
 					*p = 0;
+					copy_links = 0;
 					send_file_name(f, flist, fname, 0, 0);
+					copy_links = copy_links_saved;
 					*p = '/';
 				}
 			} else {
